@@ -19,7 +19,7 @@
 * along with this program; if not, write to the Free Software                   *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: Calculator.cpp,v 1.48 2003/10/09 21:27:48 fox Exp $                      *
+* $Id: Calculator.cpp,v 1.50 2004/03/02 16:37:19 fox Exp $                      *
 ********************************************************************************/
 #include "fx.h"
 #include "fxkeys.h"
@@ -556,6 +556,7 @@ FXColor Calculator::getClearAllColor() const {
 // Set display color
 void Calculator::setDisplayColor(FXColor clr){
   display->setBackColor(clr);
+  display->setSelTextColor(clr);
   display->setHiliteColor(makeHiliteColor(clr));
   display->setShadowColor(makeShadowColor(clr));
   }
@@ -567,6 +568,19 @@ FXColor Calculator::getDisplayColor() const {
   }
 
 
+// Set display color
+void Calculator::setDisplayNumberColor(FXColor clr){
+  display->setTextColor(clr);
+  display->setSelBackColor(clr);
+  }
+
+
+// Get display color
+FXColor Calculator::getDisplayNumberColor() const {
+  return display->getTextColor();
+  }
+
+
 // Set numeric base color
 void Calculator::setBaseColor(FXColor clr){
   FXColor hilite=FXRGB(FXREDVAL(clr)+((255-FXREDVAL(clr))*3)/8,
@@ -621,8 +635,7 @@ FXFont* Calculator::getDisplayFont() const {
 
 // Read registry
 void Calculator::readRegistry(){
-  FXFontDesc fontdesc;
-  const FXchar* fontspec;
+  FXString fontspec;
 
   // Position
   FXint xx=getApp()->reg().readIntEntry("SETTINGS","x",50);
@@ -641,6 +654,7 @@ void Calculator::readRegistry(){
   FXColor clearclr=getApp()->reg().readColorEntry("SETTINGS","clearcolor",FXRGB(238,148,0));
   FXColor clearallclr=getApp()->reg().readColorEntry("SETTINGS","clearallcolor",FXRGB(238,118,0));
   FXColor displayclr=getApp()->reg().readColorEntry("SETTINGS","displaycolor",FXRGB(255,255,255));
+  FXColor numberclr=getApp()->reg().readColorEntry("SETTINGS","displaynumbercolor",FXRGB(0,0,0));
   FXColor numbaseclr=getApp()->reg().readColorEntry("SETTINGS","numbasecolor",FXRGB(203,203,203));
   FXColor angmodeclr=getApp()->reg().readColorEntry("SETTINGS","anglemodecolor",FXRGB(203,203,203));
 
@@ -663,9 +677,9 @@ void Calculator::readRegistry(){
   recall=getApp()->reg().readRealEntry("SETTINGS","memory",0.0);
 
   // Font
-  fontspec=getApp()->reg().readStringEntry("SETTINGS","font",NULL);
-  if(fontspec && fxparsefontdesc(fontdesc,fontspec)){
-    font=new FXFont(getApp(),fontdesc);
+  fontspec=getApp()->reg().readStringEntry("SETTINGS","displayfont","");
+  if(!fontspec.empty()){
+    font=new FXFont(getApp(),fontspec);
     setDisplayFont(font);
     }
 
@@ -679,6 +693,7 @@ void Calculator::readRegistry(){
   setClearColor(clearclr);
   setClearAllColor(clearallclr);
   setDisplayColor(displayclr);
+  setDisplayNumberColor(numberclr);
   setBaseColor(numbaseclr);
   setAngleColor(angmodeclr);
 
@@ -698,8 +713,7 @@ void Calculator::readRegistry(){
 
 // Write registry
 void Calculator::writeRegistry(){
-  FXFontDesc fontdesc;
-  FXchar fontspec[200];
+  FXString fontspec;
 
   // Position
   getApp()->reg().writeIntEntry("SETTINGS","x",getX());
@@ -718,6 +732,7 @@ void Calculator::writeRegistry(){
   getApp()->reg().writeColorEntry("SETTINGS","clearcolor",getClearColor());
   getApp()->reg().writeColorEntry("SETTINGS","clearallcolor",getClearAllColor());
   getApp()->reg().writeColorEntry("SETTINGS","displaycolor",getDisplayColor());
+  getApp()->reg().writeColorEntry("SETTINGS","displaynumbercolor",getDisplayNumberColor());
   getApp()->reg().writeColorEntry("SETTINGS","numbasecolor",getBaseColor());
   getApp()->reg().writeColorEntry("SETTINGS","anglemodecolor",getAngleColor());
 
@@ -740,9 +755,8 @@ void Calculator::writeRegistry(){
   getApp()->reg().writeRealEntry("SETTINGS","memory",recall);
 
   // Font
-  getDisplayFont()->getFontDesc(fontdesc);
-  fxunparsefontdesc(fontspec,fontdesc);
-  getApp()->reg().writeStringEntry("SETTINGS","font",fontspec);
+  fontspec=getDisplayFont()->getFont();
+  getApp()->reg().writeStringEntry("SETTINGS","displayfont",fontspec.text());
   }
 
 
@@ -1197,6 +1211,7 @@ long Calculator::onCmdColor(FXObject*,FXSelector sel,void* ptr){
   FXColor clr=(FXColor)(FXuval)ptr;
   switch(FXSELID(sel)){
     case ID_COLOR_DISPLAY: setDisplayColor(clr); break;
+    case ID_COLOR_DISPLAYNUMBER: setDisplayNumberColor(clr); break;
     case ID_COLOR_DIGITS: setDigitColor(clr); break;
     case ID_COLOR_HEXDIGITS: setHexDigitColor(clr); break;
     case ID_COLOR_OPERATORS: setOperatorColor(clr); break;
@@ -1218,6 +1233,7 @@ long Calculator::onUpdColor(FXObject* sender,FXSelector sel,void*){
   FXColor clr;
   switch(FXSELID(sel)){
     case ID_COLOR_DISPLAY: clr=getDisplayColor(); break;
+    case ID_COLOR_DISPLAYNUMBER: clr=getDisplayNumberColor(); break;
     case ID_COLOR_DIGITS: clr=getDigitColor(); break;
     case ID_COLOR_HEXDIGITS: clr=getHexDigitColor(); break;
     case ID_COLOR_OPERATORS: clr=getOperatorColor(); break;
