@@ -3,7 +3,7 @@
 *                         D o c u m e n t   O b j e c t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDocument.h,v 1.9 2002/01/18 22:42:52 jeroen Exp $                      *
+* $Id: FXDocument.h,v 1.13 2004/02/08 17:17:33 fox Exp $                        *
 ********************************************************************************/
 #ifndef FXDOCUMENT_H
 #define FXDOCUMENT_H
@@ -28,6 +28,7 @@
 #include "FXObject.h"
 #endif
 
+namespace FX {
 
 
 // Forward
@@ -83,5 +84,6 @@ public:
   virtual ~FXDocument();
   };
 
-#endif
+}
 
+#endif
