@@ -3,7 +3,7 @@
 *                    F i l e   S e l e c t i o n   D i a l o g                  *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXFileDialog.cpp,v 1.34 2003/10/23 04:19:44 fox Exp $                    *
+* $Id: FXFileDialog.cpp,v 1.36 2004/02/20 21:16:57 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -200,6 +200,18 @@ FXuint FXFileDialog::getSelectMode() const {
   }
 
 
+// Change wildcard matching mode
+void FXFileDialog::setMatchMode(FXuint mode){
+  filebox->setMatchMode(mode);
+  }
+  
+
+// Return wildcard matching mode
+FXuint FXFileDialog::getMatchMode() const {
+  return filebox->getMatchMode();
+  }
+  
+
 // Show readonly button
 void FXFileDialog::showReadOnly(FXbool show){
   filebox->showReadOnly(show);
