@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGZStream.cpp,v 1.5 2004/02/08 17:29:06 fox Exp $                       *
+* $Id: FXGZStream.cpp,v 1.5.2.1 2005/03/18 05:37:07 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -59,14 +59,12 @@ unsigned long FXGZFileStream::writeBuffer(unsigned long){
   if(code==FXStreamOK){
     m=wrptr-rdptr;
     n=gzwrite((gzFile*)file,rdptr,m);
-    if(n<=0){
-      code=FXStreamFull;
-      return endptr-wrptr;
+    if(0<n){
+      m-=n;
+      if(m){memmove(begptr,rdptr+n,m);}
+      rdptr=begptr;
+      wrptr=begptr+m;
       }
-    m-=n;
-    if(m){memmove(begptr,rdptr+n,m);}
-    rdptr=begptr;
-    wrptr=begptr+m;
     return endptr-wrptr;
     }
   return 0;
@@ -86,11 +84,9 @@ unsigned long FXGZFileStream::readBuffer(unsigned long){
     rdptr=begptr;
     wrptr=begptr+m;
     n=gzread((gzFile*)file,wrptr,endptr-wrptr);
-    if(n<=0){
-      code=FXStreamEnd;
-      return wrptr-rdptr;
+    if(0<n){
+      wrptr+=n;
       }
-    wrptr+=n;
     return wrptr-rdptr;
     }
   return 0;
