@@ -3,7 +3,7 @@
 *                         T e x t   F i e l d   O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTextField.cpp,v 1.116 2003/10/23 17:53:17 fox Exp $                    *
+* $Id: FXTextField.cpp,v 1.121 2004/05/05 16:03:37 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -43,7 +43,6 @@
   Notes:
 
   - TextField passes string ptr in the SEL_COMMAND callback.
-  - GUI updatable as long as its in the focus chain.
   - Double-click should select word, triple click all of text field.
   - TextField should return 0 for all unhandled keys!
   - Pressing mouse button will set the focus w/o claiming selection!
@@ -791,34 +790,51 @@ void FXTextField::setAnchorPos(FXint pos){
   }
 
 
-// Draw the cursor
+// Draw the cursor; need to draw 2 characters around the cursor
+// due to possible overhanging in certain fonts.  Also, need to
+// completely erase and redraw because of ClearType.
+// Kudos to Bill Baxter for help with this code.
 void FXTextField::drawCursor(FXuint state){
-  FXint cl,ch,xx,len;
-  if(!xid) return;
+  FXint cl,ch,len,xx,xlo,xhi;
   if((state^flags)&FLAG_CARET){
-    FXDCWindow dc(this);
-    len=contents.length();
-    FXASSERT(0<=cursor && cursor<=len);
-    FXASSERT(0<=anchor && anchor<=len);
-    xx=coord(cursor)-1;
-    dc.setClipRectangle(border,border,width-(border<<1),height-(border<<1));
-    if(flags&FLAG_CARET){
-      dc.setForeground(backColor);
-      dc.fillRectangle(xx,padtop+border,1,height-padbottom-padtop-(border<<1));
-      dc.fillRectangle(xx-2,padtop+border,5,1);
-      dc.fillRectangle(xx-2,height-border-padbottom-1,5,1);
-      cl=cursor-1;
-      ch=cursor+1;
-      drawTextRange(dc,FXMAX(cl,0),FXMIN(ch,len));     // Gotta redraw these letters...
-      flags&=~FLAG_CARET;
-      }
-    else{
-      dc.setForeground(cursorColor);
-      dc.fillRectangle(xx,padtop+border,1,height-padbottom-padtop-(border<<1));
-      dc.fillRectangle(xx-2,padtop+border,5,1);
-      dc.fillRectangle(xx-2,height-border-padbottom-1,5,1);
-      flags|=FLAG_CARET;
+    if(xid){
+      FXDCWindow dc(this);
+      len=contents.length();
+      FXASSERT(0<=cursor && cursor<=len);
+      FXASSERT(0<=anchor && anchor<=len);
+      xx=coord(cursor)-1;
+
+      // Clip rectangle around cursor
+      xlo=FXMAX(xx-2,border);
+      xhi=FXMIN(xx+3,width-border);
+
+      // Cursor can overhang padding but not borders
+      dc.setClipRectangle(xlo,border,xhi-xlo,height-(border<<1));
+
+      // Draw I beam
+      if(state&FLAG_CARET){
+
+        // Draw I-beam
+        dc.setForeground(cursorColor);
+        dc.fillRectangle(xx,padtop+border,1,height-padbottom-padtop-(border<<1));
+        dc.fillRectangle(xx-2,padtop+border,5,1);
+        dc.fillRectangle(xx-2,height-border-padbottom-1,5,1);
+        }
+
+      // Erase I-beam
+      else{
+
+        // Erase I-beam, plus the text immediately surrounding it
+        dc.setForeground(backColor);
+        dc.fillRectangle(xx-2,border,5,height-(border<<1));
+
+        // Draw two characters before and after cursor
+        cl=cursor-2;
+        ch=cursor+2;
+        drawTextRange(dc,FXMAX(cl,0),FXMIN(ch,len));
+        }
       }
+    flags^=FLAG_CARET;
     }
   }
 
@@ -1255,8 +1271,8 @@ long FXTextField::onCmdCursorLeft(FXObject*,FXSelector,void*){
 // Find end of previous word
 FXint FXTextField::leftWord(FXint pos) const {
   FXASSERT(0<=pos && pos<=contents.length());
-  while(0<pos && !isspace(contents[pos-1]) && !strchr(delimiters,contents[pos-1])) pos--;
-  while(0<pos && isspace(contents[pos-1])) pos--;
+  while(0<pos && !isspace((FXuchar)contents[pos-1]) && !strchr(delimiters,contents[pos-1])) pos--;
+  while(0<pos && isspace((FXuchar)contents[pos-1])) pos--;
   if(0<pos && pos==cursor) pos--;
   return pos;
   }
@@ -1265,8 +1281,8 @@ FXint FXTextField::leftWord(FXint pos) const {
 // Find begin of next word
 FXint FXTextField::rightWord(FXint pos) const {
   FXASSERT(0<=pos && pos<=contents.length());
-  while(pos<contents.length() && !isspace(contents[pos]) && !strchr(delimiters,contents[pos])) pos++;
-  while(pos<contents.length() && isspace(contents[pos])) pos++;
+  while(pos<contents.length() && !isspace((FXuchar)contents[pos]) && !strchr(delimiters,contents[pos])) pos++;
+  while(pos<contents.length() && isspace((FXuchar)contents[pos])) pos++;
   if(pos<contents.length() && pos==cursor) pos++;
   return pos;
   }
@@ -1275,14 +1291,14 @@ FXint FXTextField::rightWord(FXint pos) const {
 // Find begin of a word
 FXint FXTextField::wordStart(FXint pos) const {
   FXASSERT(0<=pos && pos<=contents.length());
-  if(pos==contents.length() || isspace(contents[pos])){
-    while(0<pos && isspace(contents[pos-1])) pos--;
+  if(pos==contents.length() || isspace((FXuchar)contents[pos])){
+    while(0<pos && isspace((FXuchar)contents[pos-1])) pos--;
     }
   else if(strchr(delimiters,contents[pos])){
     while(0<pos && strchr(delimiters,contents[pos-1])) pos--;
     }
   else{
-    while(0<pos && !strchr(delimiters,contents[pos-1]) && !isspace(contents[pos-1])) pos--;
+    while(0<pos && !strchr(delimiters,contents[pos-1]) && !isspace((FXuchar)contents[pos-1])) pos--;
     }
   return pos;
   }
@@ -1291,14 +1307,14 @@ FXint FXTextField::wordStart(FXint pos) const {
 // Find end of word
 FXint FXTextField::wordEnd(FXint pos) const {
   FXASSERT(0<=pos && pos<=contents.length());
-  if(pos==contents.length() || isspace(contents[pos])){
-    while(pos<contents.length() && isspace(contents[pos])) pos++;
+  if(pos==contents.length() || isspace((FXuchar)contents[pos])){
+    while(pos<contents.length() && isspace((FXuchar)contents[pos])) pos++;
     }
   else if(strchr(delimiters,contents[pos])){
     while(pos<contents.length() && strchr(delimiters,contents[pos])) pos++;
     }
   else{
-    while(pos<contents.length() && !strchr(delimiters,contents[pos]) && !isspace(contents[pos])) pos++;
+    while(pos<contents.length() && !strchr(delimiters,contents[pos]) && !isspace((FXuchar)contents[pos])) pos++;
     }
   return pos;
   }
