@@ -3,7 +3,7 @@
 *                          T r e e L i s t   O b j e c t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1997,2003 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1997,2004 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXTreeList.cpp,v 1.133 2003/10/23 04:19:45 fox Exp $                     *
+* $Id: FXTreeList.cpp,v 1.137 2004/04/30 03:44:51 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -53,11 +53,12 @@
 */
 
 
-#define ICON_SPACING        4         // Spacing between parent and child in x direction
-#define TEXT_SPACING        4         // Spacing between icon and text
-#define SIDE_SPACING        4         // Spacing between side and item
-
-#define DEFAULT_INDENT      8         // Indent between parent and child
+#define ICON_SPACING        4   // Spacing between parent and child in x direction
+#define TEXT_SPACING        4   // Spacing between icon and text
+#define SIDE_SPACING        4   // Spacing between side and item
+#define DEFAULT_INDENT      8   // Indent between parent and child
+#define HALFBOX_SIZE        4   // Half box size
+#define BOX_FUDGE           3   // Fudge border around box
 
 
 #define SELECT_MASK         (TREELIST_SINGLESELECT|TREELIST_BROWSESELECT)
@@ -182,6 +183,12 @@ void FXTreeItem::setIconOwned(FXuint owned){
   }
 
 
+// Change has items flag
+void FXTreeItem::setHasItems(FXbool flag){
+  if(flag) state|=HASITEMS; else state&=~HASITEMS;
+  }
+
+
 // Create icon
 void FXTreeItem::create(){
   if(openIcon) openIcon->create();
@@ -377,7 +384,7 @@ FXTreeList::FXTreeList(){
 
 
 // Tree List
-FXTreeList::FXTreeList(FXComposite *p,FXint nvis,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
+FXTreeList::FXTreeList(FXComposite *p,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
   FXScrollArea(p,opts,x,y,w,h){
   flags|=FLAG_ENABLED;
   target=tgt;
@@ -396,7 +403,7 @@ FXTreeList::FXTreeList(FXComposite *p,FXint nvis,FXObject* tgt,FXSelector sel,FX
   lineColor=getApp()->getShadowColor();
   treeWidth=0;
   treeHeight=0;
-  visible=FXMAX(nvis,0);
+  visible=0;
   indent=DEFAULT_INDENT;
   grabx=0;
   graby=0;
@@ -745,10 +752,10 @@ FXint FXTreeList::hitItem(const FXTreeItem* item,FXint x,FXint y) const {
     iy=item->y;
     ih=item->getHeight(this);
     if(iy<=y && y<iy+ih){
-      if((options&TREELIST_SHOWS_BOXES) && ((item->state&FXTreeItem::HASITEMS) || item->first)){
+      if((options&TREELIST_SHOWS_BOXES) && (item->hasItems() || item->getFirst())){
         xh=ix-indent+(SIDE_SPACING/2);
         yh=iy+ih/2;
-        if(xh-4<=x && x<=xh+4 && yh-4<=y && y<=yh+4) return 3;
+        if(xh-HALFBOX_SIZE-BOX_FUDGE<=x && x<=xh+HALFBOX_SIZE+BOX_FUDGE && yh-HALFBOX_SIZE-BOX_FUDGE<=y && y<=yh+HALFBOX_SIZE+BOX_FUDGE) return 3;
         }
       hit=item->hitItem(this,x-ix,y-iy);
       }
@@ -1144,9 +1151,9 @@ long FXTreeList::onPaint(FXObject*,FXSelector,void* ptr){
             if(p->next) dc.fillRectangle(xp,y,1,h);
             p=p->parent;
             }
-          if((options&TREELIST_SHOWS_BOXES) && ((item->state&FXTreeItem::HASITEMS) || item->first)){
-            if(item->prev || item->parent) dc.fillRectangle(xh,y,1,yh-y-4);
-            if(item->next) dc.fillRectangle(xh,yh+4,1,y+h-yh-4);
+          if((options&TREELIST_SHOWS_BOXES) && (item->hasItems() || item->getFirst())){
+            if(item->prev || item->parent) dc.fillRectangle(xh,y,1,yh-y-HALFBOX_SIZE);
+            if(item->next) dc.fillRectangle(xh,yh+HALFBOX_SIZE,1,y+h-yh-HALFBOX_SIZE);
             }
           else{
             if(item->prev || item->parent) dc.fillRectangle(xh,y,1,hh);
@@ -1157,15 +1164,15 @@ long FXTreeList::onPaint(FXObject*,FXSelector,void* ptr){
           }
 
         // Boxes before items for expand/collapse of item
-        if((options&TREELIST_SHOWS_BOXES) && ((item->state&FXTreeItem::HASITEMS) || item->first)){
+        if((options&TREELIST_SHOWS_BOXES) && (item->hasItems() || item->getFirst())){
           dc.setFillStyle(FILL_OPAQUESTIPPLED);
           dc.fillRectangle(xh+4,yh,(SIDE_SPACING/2)-2,1);
           dc.setFillStyle(FILL_SOLID);
-          dc.drawRectangle(xh-4,yh-4,8,8);
+          dc.drawRectangle(xh-HALFBOX_SIZE,yh-HALFBOX_SIZE,HALFBOX_SIZE+HALFBOX_SIZE,HALFBOX_SIZE+HALFBOX_SIZE);
           dc.setForeground(textColor);
-          dc.fillRectangle(xh-2,yh,5,1);
+          dc.fillRectangle(xh-HALFBOX_SIZE+2,yh,HALFBOX_SIZE+HALFBOX_SIZE-3,1);
           if(!(options&TREELIST_AUTOSELECT) && !item->isExpanded()){
-            dc.fillRectangle(xh,yh-2,1,5);
+            dc.fillRectangle(xh,yh-HALFBOX_SIZE+2,1,HALFBOX_SIZE+HALFBOX_SIZE-3);
             }
           }
         }
@@ -1253,7 +1260,7 @@ long FXTreeList::onKeyPress(FXObject*,FXSelector,void* ptr){
     case KEY_Right:                       // Move right/down and open subtree
     case KEY_KP_Right:
       if(item){
-        if(!(options&TREELIST_AUTOSELECT) && !item->isExpanded() && ((item->state&FXTreeItem::HASITEMS) || item->first)){
+        if(!(options&TREELIST_AUTOSELECT) && !item->isExpanded() && (item->hasItems() || item->getFirst())){
           expandTree(item,TRUE);
           }
         else if(item->first){
@@ -1268,7 +1275,7 @@ long FXTreeList::onKeyPress(FXObject*,FXSelector,void* ptr){
     case KEY_Left:                        // Move left/up and close subtree
     case KEY_KP_Left:
       if(item){
-        if(!(options&TREELIST_AUTOSELECT) && item->isExpanded() && ((item->state&FXTreeItem::HASITEMS) || item->first)){
+        if(!(options&TREELIST_AUTOSELECT) && item->isExpanded() && (item->hasItems() || item->getFirst())){
           collapseTree(item,TRUE);
           }
         else if(item->parent){
